!
!    Copyright 1997-2007, 2015, 2019-2021 Guy Munhoven
!
!    This file is part of libthdyct.
!
!    Licensed under the Apache License, Version 2.0 (the "License");
!    you may not use this file except in compliance with the License.
!    You may obtain a copy of the License at
!
!        http://www.apache.org/licenses/LICENSE-2.0
!
!    Unless required by applicable law or agreed to in writing, software
!    distributed under the License is distributed on an "AS IS" BASIS,
!    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
!    See the License for the specific language governing permissions and
!    limitations under the License.
!


!     ******************************************************************
      DOUBLE PRECISION FUNCTION AK2(tk,s,d)
!     ******************************************************************
      IMPLICIT NONE
!
!     Function calculates second dissociation constant K2 in mol/kg-SW
!     on SWS pH-scale.
!     Checked Sat Jun 21 11:42:38 MET DST 1997 
!
!     Input variables:
!     s      : salinity
!     tk     : temperature in K
!     d      : depth in m
!     
      DOUBLE PRECISION tk,s,d
!     Local variables:
!     p      : applied pressure in bar
!     rt     : R*TEMP, R in bar*cm3/(mol*K)
!     tc     : temperature in degrees Celsius
!     dvi    : volume change for ionization
!     dki    : compressibility change for ionization
!     sqrts  : square root of salinity
!     ds     : salinity-34.8

      DOUBLE PRECISION p,rt,tc,dvi,dki,ds,sqrts
!
      CHARACTER (len = 62) , DIMENSION(2) :: whatid
      DATA whatid(1)
     &/'"@(#)- K_2: after Millero (1995), pH-SWS, [mol/kg-SW];"'/
      DATA whatid(2)
     &/'"@(#)       pressure correction after Millero (1982)"'/
!
       p = d/10.0D+00
      tc = tk - 273.16D+00
      ds = s - 34.8D+00
      sqrts = DSQRT(s)
      rt = 83.14510D+00*tk
!
!
      dvi = -( 15.82D+00 - 0.321D+00*ds + 0.219D-01*tc)
      dki = -( -1.13D+00 + 0.314D+00*ds + 0.1475D+00*tc)*1.0D-03
      ak2 = DEXP( -0.84226D+00 - 3741.1288D+00/tk
     >           - 1.437139D+00*DLOG(tk)
     >           + ( -0.128417D+00 - 24.41239D+00/tk)*sqrts
     >           + 0.1195308D+00*s - 0.912840D-02*s*sqrts
     >           - ( dvi - dki*p/2.D+00)*p/rt)
      RETURN
      END
