!
!    Copyright 1997-2007, 2015, 2019-2021 Guy Munhoven
!
!    This file is part of libthdyct.
!
!    Licensed under the Apache License, Version 2.0 (the "License");
!    you may not use this file except in compliance with the License.
!    You may obtain a copy of the License at
!
!        http://www.apache.org/licenses/LICENSE-2.0
!
!    Unless required by applicable law or agreed to in writing, software
!    distributed under the License is distributed on an "AS IS" BASIS,
!    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
!    See the License for the specific language governing permissions and
!    limitations under the License.
!


!     ******************************************************************
      DOUBLE PRECISION FUNCTION AKCALC(tk,s,d)
!     ******************************************************************
      IMPLICIT NONE
!
!     Function calculates calcite dissociation constant K_{Calc} in
!     (mol/kg-SW)^2
!     Checked Sat Jun 21 11:42:38 MET DST 1997 
!
!     Input variables:
!     s      : salinity
!     tk     : temperature in K
!     d      : depth in m
!     
      DOUBLE PRECISION tk,s,d
!     Local variables:
!     p      : pressure in bar
!     rt     : R*TEMP
!     tc     : temperature in degrees Celsius
!     dvi    : volume change for ionization
!     dki    : compressibility change for ionization
!     sqrts  : square root of salinity
!     ds     : salinity-34.8

      DOUBLE PRECISION p,rt,tc,dvi,dki,ds,sqrts
!
      CHARACTER (len = 62) , DIMENSION(2) :: whatid
      DATA whatid(1)
     &/'"@(#)- K_calc: after Mucci (1983), [(mol/kg-SW)^2];"'/
      DATA whatid(2)
     &/'"@(#)       pressure correction after Millero (1982)"'/
!
       p = d/10.0D+00
      tc = tk - 273.16D+00
      ds = s - 34.8D+00
      sqrts = DSQRT(s)
      rt = 83.14510D+00*tk
!
!
      dvi = -( 48.76D+00 - 0.5304D+00*tc)
      dki = -( 11.76D+00 - 0.3692D+00*tc)*1.0D-03
      akcalc = (10.D+00**( -171.9065D+00 - 0.77993D-01*tk
     >                    + 2839.319D+00/tk + 71.595D+00*DLOG10(tk)
     >                    + ( -0.77712D+00 + 0.28426D-02*tk
     >                       + 178.34D+00/tk)*sqrts - 0.7711D-01*s
     >                    + 0.41249D-02*s*sqrts) )
     >         * DEXP(- (dvi - dki*p/2.D+00)*p/rt )
      RETURN
      END
